# openapi-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.0
- Package version: 1.0.0
- Generator version: 7.19.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import openapi_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import openapi_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import openapi_client
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "http://localhost"
)



# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.DefaultApi(api_client)
    audio_bible_id = 56 # int | 

    try:
        api_response = api_instance.get_audio_bible_books(audio_bible_id)
        print("The response of DefaultApi->get_audio_bible_books:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->get_audio_bible_books: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**get_audio_bible_books**](docs/DefaultApi.md#get_audio_bible_books) | **GET** /audio_bibles/{audio_bible_id}/books | 
*DefaultApi* | [**get_audio_bible_chapters**](docs/DefaultApi.md#get_audio_bible_chapters) | **GET** /audio_bibles/{audio_bible_id}/books/{book_num}/chapters | 
*DefaultApi* | [**get_audio_bibles**](docs/DefaultApi.md#get_audio_bibles) | **GET** /audio_bibles | 
*DefaultApi* | [**get_audio_chapter**](docs/DefaultApi.md#get_audio_chapter) | **GET** /audio_bibles/{audio_bible_id}/books/{book_num}/chapters/{chapter_num} | 
*DefaultApi* | [**get_bible_books**](docs/DefaultApi.md#get_bible_books) | **GET** /bibles/{bible_id}/books | 
*DefaultApi* | [**get_bible_chapters**](docs/DefaultApi.md#get_bible_chapters) | **GET** /bibles/{bible_id}/books/{book_num}/chapters | 
*DefaultApi* | [**get_bible_verse_by_number**](docs/DefaultApi.md#get_bible_verse_by_number) | **GET** /bibles/{bible_id}/books/{book_num}/chapters/{chapter_num}/verses/{verse_num} | 
*DefaultApi* | [**get_bible_verses**](docs/DefaultApi.md#get_bible_verses) | **GET** /bibles/{bible_id}/books/{book_num}/chapters/{chapter_num}/verses | 
*DefaultApi* | [**get_random_bible_verse**](docs/DefaultApi.md#get_random_bible_verse) | **GET** /bibles/{bible_id}/random | 
*DefaultApi* | [**get_verse_of_the_day**](docs/DefaultApi.md#get_verse_of_the_day) | **GET** /bibles/{bible_id}/verse-of-the-day | 


## Documentation For Models

 - [AudioBible](docs/AudioBible.md)
 - [BibleVerse](docs/BibleVerse.md)
 - [BooksCountResponse](docs/BooksCountResponse.md)
 - [ChaptersCountResponse](docs/ChaptersCountResponse.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author




